=======
History
=======

0.2.0 (2021-03-16)
------------------

* First usable release (lots of imported content from random Kintyre developed add ons)


0.1.1 (2021-03-11)
------------------

* First release on PyPI.
